package cn.com.mjsoft.cms.metadata.dao;

import cn.com.mjsoft.framework.persistence.core.PersistenceEngine;
import cn.com.mjsoft.framework.persistence.core.support.UpdateState;
import cn.com.mjsoft.framework.security.session.SecuritySessionKeeper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

/**
 * 字典DAO
 */
@Repository
public class DictDao
{

    @Autowired
    @Qualifier("defaultMysqlPe")//TODO 非mysql版本请修改为对应的数据源名称，一般为defaultPe
    private PersistenceEngine pe;


    public UpdateState saveDicWordsType(String dicTypeName, String typeFlag, String linear)
    {
        String sql = "insert into dic_type ( dicTypeName, typeFlag, linearFlag ) values (?, ?, ?) ";

        return pe.insert( sql , new Object[] { dicTypeName, typeFlag, linear } );
    }

    public void updatDicWordsType( String dicTypeName, String typeFlag )
    {
        String sql = "update dic_type set dicTypeName=? where typeFlag=?";

        pe.update( sql, new Object[] { dicTypeName, typeFlag } );
    }

    public UpdateState saveDicWord( Map<String, Object> params)
    {
        String sql = "insert into dic_words ( dicType, dicWord, dicFlag, orderFlag, linearFlag, val) values (?, ?, ?, ?, ?, ?) ";

        return pe.insert( sql, params);
    }


    public void updatFirstDicWordsOrderByType( String typeFlag, String dicFlag )
    {
        String sql = "update dic_words set orderFlag=1 where dicFlag=?";

        pe.update( sql, new Object[] { dicFlag } );
    }

    public void updateMaxDicWordsOrderByType( String typeFlag, String dicFlag )
    {
        String sql = "update dic_words set orderFlag=(select tmp.maxOrder from ( SELECT max( orderFlag ) + 1 maxOrder FROM dic_words WHERE dicType=? ) tmp) where dicFlag=?";

        pe.update( sql, new Object[] { typeFlag, dicFlag } );
    }

    public List queryAllDicWordsType()
    {
        String sql = "select * from dic_type order by linearFlag asc";

        return pe.queryResultMap( sql );
    }

    public List queryAllDicRelateField()
    {
        String sql = "select * from model_html_config mc inner join model_filed_metadata fm where fm.metaDataId=mc.metaDataId and (choiceValue like 'dicField=%' or choiceValue like 'dicType=%')";

        return pe.queryResultMap( sql );
    }

    public Map<String, ?> querySingleDicWordsType( String flag )
    {
        String sql = "select * from dic_type where typeFlag=?";

        return pe.querySingleResultMap( sql, new Object[] { flag } );
    }

    public List<Map<String, String>> queryDicWordsByLinear( String linear )
    {
        String sql = "select * from dic_words where linearFlag like ? order by linearFlag asc";

        return pe.queryResultMap( sql, new Object[] { linear + "%" } );
    }

    public List<Map> queryDicWordsByType( String typeFlag )
    {
        String sql = "select * from dic_words where dicType=? order by linearFlag asc";

        return pe.queryResultMap( sql, new Object[] { typeFlag } );
    }

    public List<Map<String, String>> queryDicWordsFlag()
    {
        String sql = "select dicWord as dicTypeName, dicFlag as typeFlag from dic_words order by linearFlag asc";

        return pe.queryResultMap( sql );
    }

    public Map<String, ?> querySingleDicWord( String typeFlag, String val )
    {
        String sql = "select * from dic_words where dicType=? and val=?";

        return pe.querySingleResultMap( sql, new Object[] { typeFlag, val } );
    }

    public Map querySingleDicWord( String dicFlag )
    {
        String sql = "select * from dic_words where dicFlag=?";

        return pe.querySingleResultMap( sql, new Object[] { dicFlag } );
    }

    public Integer queryDicWordCount( String linear )
    {
        String sql = "select count(*) from dic_words where linearFlag like ?";

        return (Integer) pe.querySingleObject( sql, new Object[] { linear+"%" }, Integer.class );
    }

    public void updateDicWord( String dicFlag, String name, String val )
    {
        String sql = "update dic_words set dicWord=?, val=? where dicFlag=?";

        pe.update( sql, new Object[] { name, val, dicFlag } );
    }

    public Map querySingleDicWordType( String typeFlag )
    {
        String sql = "select * from dic_type where typeFlag=?";

        return pe.querySingleResultMap( sql, new Object[] { typeFlag } );
    }

    public void deleteDicWord( String flag )
    {
        String sql = "delete from dic_words where dicFlag=?";

        pe.update( sql, new Object[] { flag } );
    }

    public void deleteDicWordByType( String dicType )
    {
        String sql = "delete from dic_words where dicType=?";

        pe.update( sql, new Object[] { dicType } );
    }

    public void deleteDicWordByLinear( String linear )
    {
        String sql = "delete from dic_words where linearFlag like ?";

        pe.update( sql, new Object[] { linear+"%" } );
    }

    public void deleteDicMainType( String type )
    {
        String sql = "delete from dic_type where typeFlag=?";

        pe.update( sql, new Object[] { type } );
    }


    public Integer querySystemTableFlagExist( String table, String flagName,
                                              String val )
    {
        //只允许登录管理员使用
        boolean isMana = SecuritySessionKeeper.getSecuritySession().isManager();

        if(!isMana)
        {
            return null;
        }

        String sql = "select count(*) from " + table + " where " + flagName
                + "=?";

        return ( Integer ) pe.querySingleObject( sql, new Object[] { val },
                Integer.class );
    }



}
