package cn.com.mjsoft.cms.metadata.service;

import ch.qos.logback.classic.Logger;
import cn.com.mjsoft.cms.cluster.adapter.ClusterCacheAdapter;
import cn.com.mjsoft.cms.common.ServiceUtil;
import cn.com.mjsoft.cms.common.spring.SpringContextUtils;
import cn.com.mjsoft.cms.metadata.dao.DictDao;
import cn.com.mjsoft.framework.cache.Cache;
import cn.com.mjsoft.framework.persistence.core.PersistenceEngine;
import cn.com.mjsoft.framework.util.StringUtil;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 字典业务类
 */
@Service
public class DictService
{
    private static final Logger log = (Logger) LoggerFactory.getLogger( DictService.class );

    public static MetaDataService getInstance()
    {
        return SpringContextUtils.getBean("dictService");
    }

    public static Cache dictCache = new ClusterCacheAdapter( 30000,
            "dictService.dictCache" );

    //TODO 如以上编译报错无ClusterCacheAdapter接口请使用以下LRUCache替代
    //public static Cache dictCache = new LRUCache( 30000 );

    @Autowired
    @Qualifier("defaultMysqlPe")//TODO 非mysql版本请修改为对应的数据源名称，一般为defaultPe
    public PersistenceEngine dbEngine;

    @Autowired
    private DictDao dictDao;

    /**
     * 添加新的字典词类型
     * @param typeName
     * @param flag
     */
    public void addDicType( String typeName, String flag )
    {
        char[] chr = typeName.toCharArray();

        StringBuilder buf = new StringBuilder();

        for ( char ch : chr )
        {
            buf.append( StringUtil.getFirstPY( ch ).toString() );
        }

        flag = buf.toString();

        try
        {
            dbEngine.beginTransaction();

            if( haveSameTypeFlag( flag ) )
            {
                flag = flag + "0";

                while ( haveSameFlag( flag ) )
                {
                    flag = flag + "0";
                }
            }

            String newLinearFlag = null;

            // 上级没有子,由于是一级类型，肯定是无子的

            // 获取最后一个兄弟
            List<Map> tps =dictDao.queryAllDicWordsType();

            String layerLinear = "001";

            if( !tps.isEmpty() )
            {
                layerLinear = (String) tps.get(tps.size()-1).get("linearFlag");

                newLinearFlag = ServiceUtil.increaseLayerLinear(
                        layerLinear, false );
            }
            else
            {
                newLinearFlag = ServiceUtil.increaseLayerLinear(
                        layerLinear, true );
            }

           dictDao.saveDicWordsType( typeName, flag, newLinearFlag );

            dbEngine.commit();
        }
        finally
        {
            dbEngine.endTransaction();

            resetCache();
        }
    }



    public void editDicType( String typeName, String flag )
    {
       dictDao.updatDicWordsType( typeName, flag );

        resetCache();
    }

    public boolean haveSameFlag( String flag )
    {
        Integer count = dictDao.querySystemTableFlagExist( "dic_words", "dicFlag", flag );

        return count > 0;
    }

    public boolean haveSameTypeFlag( String flag )
    {
        Integer count = dictDao.querySystemTableFlagExist( "dic_type", "typeFlag", flag );

        return count.intValue() > 0;
    }

    /**
     * 导入新的字典词
     * @param params
     * @return
     */
    public void importDicWord( String dicType, String dword )
    {
        if( dword == null )
        {
            return;
        }

        String[] dws = StringUtil.split( dword, "\n" );

        for ( String dw : dws )
        {
            if (StringUtil.isStringNotNull(dw) && !haveSameFlag(dw.trim()))
            {

                String[] dwsa = dw.trim().split( "=" );

                if( dwsa.length == 2 && StringUtil.isStringNotNull( dwsa[1] ))
                {
                    Map<String, Object> params = new HashMap<>();
                    params.put("dicWord", dwsa[0]);
                    params.put("val", dwsa[1]);
                    params.put("dicType", dicType);

                    addDicWord( params );
                }
            }
        }
    }



    /**
     * 添加新的字典词
     * @param params
     * @return
     */
    public String addDicWord( Map<String, Object> params )
    {

        String dicWord = (String) params.get("dicWord");

        char[] chr = dicWord.toCharArray();

        StringBuilder buf = new StringBuilder();

        for ( char ch : chr )
        {
            buf.append( StringUtil.getFirstPY( ch ).toString() );
        }

        String flag = buf.toString();

        if( haveSameFlag( flag ) )
        {
            flag = flag + "0";

            while ( haveSameFlag( flag ) )
            {
                flag = flag + "0";
            }
        }

        params.put("dicFlag",  flag);

        boolean noDicWord = false;

        try
        {
            dbEngine.beginTransaction();

            List testDicWord =dictDao.queryDicWordsByType( (String)params.get("dicType") );


            if( testDicWord.isEmpty())
            {
                noDicWord = true;
            }

            String newLinearFlag = null;

            // 上级没有子,由于是一级类型，肯定是无子的

            // 获取最后一个兄弟

            String type = (String) params.get("dicType");

            List<Map> tps =dictDao.queryDicWordsByType(type);

            String layerLinear = null;

            if( !tps.isEmpty() )
            {
                layerLinear = (String) tps.get(tps.size()-1).get("linearFlag");

                newLinearFlag = ServiceUtil.increaseLayerLinear(
                        layerLinear, false );
            }
            else
            {
                //上级
                Map<String, ?> dicType =dictDao.querySingleDicWordsType(type);

                if(dicType.isEmpty())//不是主分类，继续取联动
                {
                    dicType =dictDao.querySingleDicWord(type);
                }

                layerLinear = dicType != null ? (String) dicType.get("linearFlag") : "";

                newLinearFlag = ServiceUtil.increaseLayerLinear(
                        layerLinear, true );
            }

            params.put("linearFlag", newLinearFlag);

            dictDao.saveDicWord( params );

            dbEngine.commit();
        }
        finally
        {
            dbEngine.endTransaction();
        }

        if( noDicWord )
        {
           dictDao.updatFirstDicWordsOrderByType( (String) params.get("dicType"), (String) params.get("dicFlag") );
        }
        else
        {
           dictDao.updateMaxDicWordsOrderByType( (String) params.get("dicType"), (String) params.get("dicFlag") );
        }

        resetCache();

        return flag;
    }

    public List<Map<String, String>> retrieveAllDicWordsType( )
    {
        //List<Map<String, String>> wordsType =dictDao.queryAllDicWordsType();

        List<Map<String, String>> wordsType = new ArrayList<>();

        wordsType.addAll(dictDao.queryDicWordsFlag() );

        return wordsType;
    }

    public List<Map<String, String>> retrieveMainDicWordsType( )
    {
        List<Map<String, String>> wordsType =dictDao.queryAllDicWordsType();


        return wordsType;
    }

    /**
     * 获取所有一级字典分类和已挂靠字典的字段
     * @return
     */
    public List<Map<String, String>> retrieveMainDicWordsTypeAndFieldRelate( )
    {
        List<Map<String, String>> relate = new ArrayList<>();
        //主分类可选
        List<Map<String, ?>> typeList =dictDao.queryAllDicWordsType();

        Map<String, String> fType = null;

        for(Map<String, ?> field : typeList)
        {
            fType = new HashMap<>();

            fType.put( "typeName", (String) field.get("dicTypeName"));
            fType.put( "typeVal", "dicType="+(String) field.get("typeFlag"));

            relate.add(fType);
        }


        fType = new HashMap<>();

        fType.put( "typeName", "============以上为字典主分类============");
        fType.put( "typeVal", "==");

        relate.add(fType);

        //关联字典的字段作为分类可选
        List<Map<String, ?>> fieldList = dictDao.queryAllDicRelateField();

        fType = null;

        for(Map<String, ?> field : fieldList)
        {
            fType = new HashMap<>();

            fType.put( "typeName", (String) field.get("showName"));
            fType.put( "typeVal", "dicField="+(String) field.get("filedSign"));

            relate.add(fType);
        }

        return relate;
    }

    public Map<String, ?> retrieveSingleMainDicWordsType( String type )
    {
        Map<String, ?> dicType =dictDao.querySingleDicWordsType(type);

        return dicType;
    }



    public List<Map> retrieveDicWordsList( String typeFlag )
    {
        String key = "retrieveDicWordsList:"+typeFlag;

        List<Map> result = (List<Map>) dictCache.getEntry(key);

        if(result == null)
        {
            result = dictDao.queryDicWordsByType(typeFlag);

            dictCache.putEntry(key,result);
        }

        return result;
    }

    public List<Map<String, String>> retrieveDicWordsListByLinear( String linear )
    {
        List<Map<String, String>> words =dictDao.queryDicWordsByLinear(linear);

        return words;
    }

    public String [] retrieveDicWords( String typeFlag )
    {
        String key = "retrieveDicWords:"+typeFlag;

        String [] result = (String[]) dictCache.getEntry(key);

        if(result == null)
        {
            List<Map> words = dictDao.queryDicWordsByType(typeFlag);

            List<String> res = new ArrayList<>();

            String word = null;

            String val = null;

            String flag = null;

            for (Map dic : words)
            {
                word = (String) dic.get("dicWord");

                val = (String) dic.get("val");

                flag = (String) dic.get("dicFlag");

                res.add(word + "=" + val + "#!#" + flag);
            }

            result = res.toArray( new String []{});

            dictCache.putEntry(key, result);
        }

        return result;
    }

    public String retrieveChildDicWordsOptList( String typeFlag, String pval )
    {
        String key = "retrieveChildDicWordsOptList:"+typeFlag+"|"+pval;

        String result = (String) dictCache.getEntry(key);

        if(result == null)
        {
            Map parent =dictDao.querySingleDicWord( typeFlag, pval);

            //上级的flag,就是下级的typeFlag
            String dicType = (String) parent.get("dicFlag");

            List<Map> words =dictDao.queryDicWordsByType(typeFlag);

            StringBuilder res = new StringBuilder();

            String word = null;

            String val = null;

            res.append( "<option value=''  dicType=''>请选择</option>" );

            for(Map dic : words)
            {
                word = (String) dic.get("dicWord");

                val = (String) dic.get("dicFlag")+"*"+(String) dic.get("val");

                res.append( "<option value='"+val+"'  dicType='"+(String) dic.get("dicFlag")+"'>"+word+"</option>" );
            }

            result = res.toString();

            dictCache.putEntry(key, result);
        }

        return result;
    }

    public Map retrieveSingleDicWord( String typeFlag, String val )
    {
        return dictDao.querySingleDicWord( typeFlag, val );
    }

    public Map retrieveSingleDicWord( String dicFlag )
    {
        String key = "retrieveSingleDicWord:"+dicFlag;

        Map result = (Map) dictCache.getEntry(key);

        if(result == null)
        {
            result = dictDao.querySingleDicWord( dicFlag );

            dictCache.putEntry(key,result);
        }

        return result;
    }


    public Object getDicWordCount( String linear )
    {
        return dictDao.queryDicWordCount( linear );
    }

    /**
     * 按照排序linear删除词汇子字典
     * @param flags
     */
    public void deleteDicWordAndChildDic( List<String> flags )
    {
        try
        {
            dbEngine.beginTransaction();

            for(String flag : flags)
            {
                Map<String, ?> dic =dictDao.querySingleDicWord(flag);

                String linear = (String) dic.get("linearFlag");

               dictDao.deleteDicWordByLinear(linear);

               dictDao.deleteDicWord(flag);
            }

            dbEngine.commit();
        }
        finally
        {
            dbEngine.endTransaction();

            resetCache();
        }
    }

    public void editDicWord( String flag, String name, String val)
    {
       dictDao.updateDicWord(flag, name, val);

        resetCache();
    }

    /**
     * 按照排序linear删除主分类的所有字典
     * @param dicType
     */
    public void deleteDicWordByLinear( String dicType )
    {
        try
        {
            dbEngine.beginTransaction();

            Map<String, ?> dt =dictDao.querySingleDicWordsType( dicType );

            String linear = (String) dt.get("linearFlag");

           dictDao.deleteDicWordByLinear(linear);

            dbEngine.commit();
        }
        finally
        {
            dbEngine.endTransaction();

            resetCache();
        }
    }

    public void deleteDicWordByType( String dicType )
    {

        List<Map> childList =dictDao.queryDicWordsByType( dicType );

        if( childList.isEmpty())
        {
            return;
        }

        for( Map child : childList)
        {
            deleteDicWordByType((String) child.get("dicFlag"));
        }

       dictDao.deleteDicWordByType(dicType);

       dictDao.deleteDicWord( dicType );

    }

    public Object getDicMainType( String type )
    {
        return dictDao.querySingleDicWordsType(type);
    }

    public void deleteDicMainType( String type )
    {
       dictDao.deleteDicMainType( type );

       resetCache();
    }


    public static void resetCache()
    {
        dictCache.clearAllEntry();
    }


}
